@@ -7,6 +7,9 @@ from .removebg import removebg
 from .pixelate import pixelate
 from .blur import blur
 from .stack import stack
+from .render import render
+
+
 
 CONTEXT_SETTINGS = dict(
         help_option_names = [
@@ -19,6 +22,8 @@ CONTEXT_SETTINGS = dict(
 def main():
     pass
 
+
+main.add_command(render)
 main.add_command(stack)
 main.add_command(blur)
 main.add_command(pixelate)
